@@ -52,17 +52,6 @@
 
 #define BENCH_INTERVAL 0.1
 
-static void NORETURN PRINTF_STYLE(1,2)
-die(const char *format, ...)
-{
-  va_list args;
-  va_start(args, format);
-  vfprintf(stderr, format, args);
-  va_end(args);
-
-  exit(EXIT_FAILURE);
-}
-
 static void *
 xalloc (size_t size)
 {
