@@ -41,12 +41,6 @@
 #define GMP_HAVE_mpz_limbs_read 0
 #endif
 
-#ifdef mpn_copyd
-#define GMP_HAVE_mpn_copyd 1
-#else
-#define GMP_HAVE_mpn_copyd 0
-#endif
-
 /* Name mangling. */
 #if !GMP_HAVE_mpz_limbs_read
 #define mpz_limbs_read _nettle_mpz_limbs_read
@@ -56,16 +50,6 @@
 #define mpz_roinit_n _nettle_mpz_roinit_n
 #endif
 
-#if !GMP_HAVE_mpn_copyd
-#define mpn_copyd _nettle_mpn_copyd
-#define mpn_copyi _nettle_mpn_copyi
-#define mpn_zero  _nettle_mpn_zero
-#endif
-
-#ifndef mpn_sqr
-#define mpn_sqr(rp, ap, n) mpn_mul_n((rp), (ap), (ap), (n))
-#endif
-
 #define cnd_swap _nettle_cnd_swap
 #define mpz_limbs_cmp _nettle_mpz_limbs_cmp
 #define mpz_limbs_read_n _nettle_mpz_limbs_read_n
@@ -130,20 +114,6 @@ mpz_roinit_n (mpz_ptr x, const mp_limb_t *xp, mp_size_t xs);
 
 #endif /* !GMP_HAVE_mpz_limbs_read */
 
-#if !GMP_HAVE_mpn_copyd
-/* Copy elements, backwards */
-void
-mpn_copyd (mp_ptr dst, mp_srcptr src, mp_size_t n);
-
-/* Copy elements, forwards */
-void
-mpn_copyi (mp_ptr dst, mp_srcptr src, mp_size_t n);
-
-/* Zero elements */
-void
-mpn_zero (mp_ptr ptr, mp_size_t n);
-#endif /* !GMP_HAVE_mpn_copyd */
-
 void
 cnd_swap (mp_limb_t cnd, mp_limb_t *ap, mp_limb_t *bp, mp_size_t n);
 
