@@ -34,8 +34,11 @@
 #endif
 
 #include <stddef.h>
+
 #include "nettle-meta.h"
 
+#undef nettle_hashes
+
 const struct nettle_hash * const nettle_hashes[] = {
   &nettle_md2,
   &nettle_md4,
@@ -46,5 +49,15 @@ const struct nettle_hash * const nettle_hashes[] = {
   &nettle_sha256,
   &nettle_sha384,
   &nettle_sha512,
+  &nettle_sha3_224,
+  &nettle_sha3_256,
+  &nettle_sha3_384,
+  &nettle_sha3_512,
   NULL
 };
+
+const struct nettle_hash * const *
+nettle_get_hashes (void)
+{
+  return nettle_hashes;
+}
